Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Handle ¶
type Handle interface {
Repository() *git.Repository
Submodule(submodulePath string) (SubmoduleHandle, error)
Submodules() []SubmoduleHandle
ReadBlobObjectContent(hash plumbing.Hash) ([]byte, error)
GetCommitTree(hash plumbing.Hash) (TreeHandle, error)
}
Handle is a solution to get away from the worktree when working with the git repository, caching the necessary data from the worktree during initialization, and then working exclusively with git objects.
type SubmoduleHandle ¶
type SubmoduleHandle interface {
Handle
Config() *config.Submodule
Status() *git.SubmoduleStatus
}
Click to show internal directories.
Click to hide internal directories.